//                              -*- Mode: C++ -*- 
// 
// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
// 
// main.h -- 
// 
// Author           : Richard A. Stroobosscher
// Created On       : Tue Apr 28 16:06:46 1992
// Last Modified By : Peter A. Buhr
// Last Modified On : Wed Oct 16 10:54:47 2002
// Update Count     : 26
// 

#ifndef __MAIN_H__
#define __MAIN_H__

#include <iostream>

using std::istream;
using std::ostream;

extern istream *yyin;
extern ostream *yyout;

extern bool error;
extern bool Yield;					// name "yield" already taken
extern bool verify;
extern bool trace;
extern bool profile;
extern bool gnu;
extern bool user;

int main( int argc, char *argv[] );

#endif // __MAIN_H__

// Local Variables: //
// compile-command: "gmake install" //
// End: //
